@@ -7,17 +7,18 @@
 #
 #   The Apache License, Version 2.0, January 2004
 #
-use strict; 
+use strict;
 package CPAN::Reporter::Config;
 BEGIN {
-  $CPAN::Reporter::Config::VERSION = '1.18_06';
+  $CPAN::Reporter::Config::VERSION = '1.19_03';
 }
 # ABSTRACT: Config file options for CPAN::Reporter
 
 use Config::Tiny 2.08 ();
-use File::HomeDir 0.58 (); 
-use File::Path (qw/mkpath/);
+use File::HomeDir 0.58 ();
+use File::Path qw/mkpath/;
 use File::Spec 3.19 ();
+use IPC::Cmd 0.46 ();
 use IO::File ();
 use CPAN 1.9301 (); # for printing warnings
 
@@ -32,11 +33,11 @@ if ( $^O eq 'darwin' ) {
     my $new = File::Spec->catdir(File::HomeDir->my_home,".cpanreporter");
     if ( ( -d $old ) && (! -d $new ) ) {
         $CPAN::Frontend->mywarn( << "HERE");
-CPAN::Reporter: since CPAN::Reporter 0.28_51, the Mac OSX config directory 
-has changed. 
+CPAN::Reporter: since CPAN::Reporter 0.28_51, the Mac OSX config directory
+has changed.
 
   Old: $old
-  New: $new  
+  New: $new
 
 Your existing configuration file will be moved automatically.
 HERE
@@ -62,7 +63,7 @@ HERE
 sub _configure {
     my $config_dir = _get_config_dir();
     my $config_file = _get_config_file();
-    
+
     mkpath $config_dir if ! -d $config_dir;
     if ( ! -d $config_dir ) {
         $CPAN::Frontend->myprint(
@@ -73,10 +74,10 @@ sub _configure {
 
     my $config;
     my $existing_options;
-    
+
     # explain grade:action pairs
     $CPAN::Frontend->myprint( _grade_action_prompt() );
-    
+
     # read or create
     if ( -f $config_file ) {
         $CPAN::Frontend->myprint(
@@ -101,7 +102,7 @@ sub _configure {
         );
         $config = Config::Tiny->new();
     }
-    
+
     my %spec = _config_spec();
 
     for my $k ( _config_order() ) {
@@ -117,10 +118,10 @@ sub _configure {
             }
             # repeat until validated
             PROMPT:
-            while ( defined ( 
+            while ( defined (
                 my $answer = CPAN::Shell::colorable_makemaker_prompt(
-                    "$k?", 
-                    $existing_options->{$k} || $option_data->{default} 
+                    "$k?",
+                    $existing_options->{$k} || $option_data->{default}
                 )
             )) {
                 if  ( ! $option_data->{validate} ||
@@ -133,12 +134,12 @@ sub _configure {
         }
         else {
             # only initialize options without default if
-            # answer matches non white space and validates, 
+            # answer matches non white space and validates,
             # otherwise reset it
-            my $answer = CPAN::Shell::colorable_makemaker_prompt( 
-                "$k?", 
-                $existing_options->{$k} || q{} 
-            ); 
+            my $answer = CPAN::Shell::colorable_makemaker_prompt(
+                "$k?",
+                $existing_options->{$k} || q{}
+            );
             if ( $answer =~ /\S/ ) {
                 $config->{_}{$k} = $answer;
             }
@@ -155,19 +156,19 @@ sub _configure {
         "\nYour CPAN::Reporter config file also contains these advanced " .
           "options:\n\n") if keys %$existing_options;
     for my $k ( keys %$existing_options ) {
-        $config->{_}{$k} = CPAN::Shell::colorable_makemaker_prompt( 
-            "$k?", $existing_options->{$k} 
-        ); 
+        $config->{_}{$k} = CPAN::Shell::colorable_makemaker_prompt(
+            "$k?", $existing_options->{$k}
+        );
     }
 
-    $CPAN::Frontend->myprint( 
+    $CPAN::Frontend->myprint(
         "\nCPAN::Reporter: writing config file to '$config_file'.\n"
     );
     if ( $config->write( $config_file ) ) {
         return $config->{_};
     }
     else {
-        $CPAN::Frontend->mywarn( "\nCPAN::Reporter: error writing config file to '$config_file':\n" 
+        $CPAN::Frontend->mywarn( "\nCPAN::Reporter: error writing config file to '$config_file':\n"
             .  Config::Tiny->errstr(). "\n");
         return;
     }
@@ -178,16 +179,16 @@ sub _configure {
 #--------------------------------------------------------------------------#
 
 #--------------------------------------------------------------------------#
-# _config_order -- determines order of interactive config.  Only items 
+# _config_order -- determines order of interactive config.  Only items
 # in interactive config will be written to a starter config file
 #--------------------------------------------------------------------------#
 
 sub _config_order {
-    return qw(  
-        email_from 
-        smtp_server 
-        edit_report 
+    return qw(
+        email_from
+        edit_report
         send_report
+        transport
     );
 }
 
@@ -205,37 +206,26 @@ sub _config_order {
 my %option_specs = (
     email_from => {
         default => '',
-        prompt => 'What email address will be used for sending reports?',
+        prompt => 'What email address will be used to reference your reports?',
         info => <<'HERE',
-CPAN::Reporter requires a valid email address as the return address
-for test reports sent to cpan-testers\@perl.org.  Either provide just
-an email address, or put your real name in double-quote marks followed 
-by your email address in angle marks, e.g. "John Doe" <jdoe@nowhere.com>.
-Note: unless this email address is subscribed to the cpan-testers mailing
-list, your test reports will not appear until manually reviewed.
+CPAN::Reporter requires a valid email address to identify senders
+in the body of a test report.  Please use a standard email format
+like: "John Doe" <jdoe@example.com>
 HERE
     },
     smtp_server => {
-        default => undef, # optional
-        info => <<'HERE',
-If your computer is behind a firewall or your ISP blocks
-outbound mail traffic, CPAN::Reporter will not be able to send
-test reports unless you provide an alternate outbound (SMTP) 
-email server.  Enter the full name of your outbound mail server
-(e.g. smtp.your-ISP.com) or leave this blank to send mail 
-directly to perl.org.  Use a space character to reset this value
-to sending to perl.org.
-HERE
+        default => undef, # (deprecated)
+        prompt  => "[DEPRECATED] It's safe to remove this from your config file.",
     },
     edit_report => {
         default => 'default:ask/no pass/na:no',
         prompt => "Do you want to review or edit the test report?",
         validate => \&_validate_grade_action_pair,
         info => <<'HERE',
-Before test reports are sent, you may want to review or edit the test 
-report and add additional comments about the result or about your system 
+Before test reports are sent, you may want to review or edit the test
+report and add additional comments about the result or about your system
 or Perl configuration.  By default, CPAN::Reporter will ask after
-each report is generated whether or not you would like to edit the 
+each report is generated whether or not you would like to edit the
 report. This option takes "grade:action" pairs.
 HERE
     },
@@ -245,10 +235,22 @@ HERE
         validate => \&_validate_grade_action_pair,
         info => <<'HERE',
 By default, CPAN::Reporter will prompt you for confirmation that
-the test report should be sent before actually emailing the 
-report.  This gives the opportunity to bypass sending particular
-reports if you need to (e.g. if you caused the failure).
-This option takes "grade:action" pairs.
+the test report should be sent before actually doing it. This
+gives the opportunity to skip sending particular reports if
+you need to (e.g. if you caused the failure). This option takes
+"grade:action" pairs.
+HERE
+    },
+    transport => {
+        default  => 'Metabase uri https://metabase.cpantesters.org/api/v1/ id_file metabase_id.json',
+        prompt   => 'Which transport system will be used to transmit the reports?',
+        validate => \&_validate_transport,
+        info     => <<'HERE',
+CPAN::Reporter sends your reports over HTTPS using Metabase. This option lets
+you set a different uri, transport mechanism and metabase profile path. If you
+are receiving HTTPS errors, you may change the uri to use plain HTTP, though
+this is not recommended. Unless you know what you're doing, just accept
+the default value.
 HERE
     },
     send_duplicates => {
@@ -258,13 +260,13 @@ HERE
         info => <<'HERE',
 CPAN::Reporter records tests grades for each distribution, version and
 platform.  By default, duplicates of previous results will not be sent at
-all, regardless of the value of the "send_report" option.  This option takes 
+all, regardless of the value of the "send_report" option.  This option takes
 "grade:action" pairs.
 HERE
     },
     send_PL_report => {
         prompt => "Do you want to send the PL report?",
-        default => undef, 
+        default => undef,
         validate => \&_validate_grade_action_pair,
     },
     send_make_report => {
@@ -298,9 +300,6 @@ HERE
     editor => {
         default => undef,
     },
-    transport => {
-        default => undef,
-    },
     debug => {
         default => undef,
     },
@@ -308,13 +307,34 @@ HERE
 
 sub _config_spec { return %option_specs }
 
+#--------------------------------------------------------------------------#
+# _generate_profile
+#
+# Run 'metabase-profile' in the .cpanreporter directory
+#--------------------------------------------------------------------------#
+
+sub _generate_profile {
+    my ($id_file) = @_;
+
+    my $cmd = IPC::Cmd::can_run('metabase-profile');
+    if ( $cmd ) {
+        return scalar IPC::Cmd::run(
+            command => [$cmd, "--output", $id_file],
+            verbose => 1,
+        );
+    }
+    else {
+        return 0;
+    }
+}
+
 #--------------------------------------------------------------------------#
 # _get_config_dir
 #--------------------------------------------------------------------------#
 
 sub _get_config_dir {
-    if ( defined $ENV{PERL_CPAN_REPORTER_DIR} && 
-         length  $ENV{PERL_CPAN_REPORTER_DIR} 
+    if ( defined $ENV{PERL_CPAN_REPORTER_DIR} &&
+         length  $ENV{PERL_CPAN_REPORTER_DIR}
     ) {
         return $ENV{PERL_CPAN_REPORTER_DIR};
     }
@@ -335,7 +355,7 @@ sub _get_config_dir {
 
 sub _get_config_file {
     if (  defined $ENV{PERL_CPAN_REPORTER_CONFIG} &&
-          length  $ENV{PERL_CPAN_REPORTER_CONFIG} 
+          length  $ENV{PERL_CPAN_REPORTER_CONFIG}
     ) {
         return $ENV{PERL_CPAN_REPORTER_CONFIG};
     }
@@ -386,12 +406,12 @@ pairs that determine what grade-specific action to take for that option.
 These pairs should be space-separated and are processed left-to-right. See
 CPAN::Reporter documentation for more details.
 
-    GRADE   :   ACTION  ======> EXAMPLES        
-    -------     -------         --------    
+    GRADE   :   ACTION  ======> EXAMPLES
+    -------     -------         --------
     pass        yes             default:no
     fail        no              default:yes pass:no
     unknown     ask/no          default:ask/no pass:yes fail:no
-    na          ask/yes         
+    na          ask/yes
     default
 
 HERE
@@ -426,7 +446,7 @@ sub _open_config_file {
     my $config = Config::Tiny->read( $config_file )
         or $CPAN::Frontend->mywarn("CPAN::Reporter: couldn't read configuration file " .
                 "'$config_file': \n" . Config::Tiny->errstr() . "\n");
-    return $config; 
+    return $config;
 }
 
 #--------------------------------------------------------------------------#
@@ -442,8 +462,8 @@ sub _validate {
 }
 
 #--------------------------------------------------------------------------#
-# _validate_grade_action 
-# returns hash of grade => action 
+# _validate_grade_action
+# returns hash of grade => action
 # returns undef
 #--------------------------------------------------------------------------#
 
@@ -452,7 +472,7 @@ sub _validate_grade_action_pair {
     $option ||= "no";
 
     my %ga_map; # grade => action
-    
+
     PAIR: for my $grade_action ( split q{ }, $option ) {
         my ($grade_list,$action);
 
@@ -477,27 +497,27 @@ sub _validate_grade_action_pair {
         }
         else {
             # something weird, so warn and skip
-            $CPAN::Frontend->mywarn( 
-                "\nCPAN::Reporter: ignoring invalid grade:action '$grade_action' for '$name'.\n\n" 
+            $CPAN::Frontend->mywarn(
+                "\nCPAN::Reporter: ignoring invalid grade:action '$grade_action' for '$name'.\n\n"
             );
             next PAIR;
         }
-        
+
         # check gradelist
         my %grades = map { ($_,1) } split( "/", $grade_list);
-        for my $g ( keys %grades ) { 
+        for my $g ( keys %grades ) {
             if ( ! _is_valid_grade($g) ) {
-                $CPAN::Frontend->mywarn( 
-                    "\nCPAN::Reporter: ignoring invalid grade '$g' in '$grade_action' for '$name'.\n\n" 
+                $CPAN::Frontend->mywarn(
+                    "\nCPAN::Reporter: ignoring invalid grade '$g' in '$grade_action' for '$name'.\n\n"
                 );
                 delete $grades{$g};
             }
         }
-        
+
         # check action
         if ( ! _is_valid_action($action) ) {
-            $CPAN::Frontend->mywarn( 
-                "\nCPAN::Reporter: ignoring invalid action '$action' in '$grade_action' for '$name'.\n\n" 
+            $CPAN::Frontend->mywarn(
+                "\nCPAN::Reporter: ignoring invalid action '$action' in '$grade_action' for '$name'.\n\n"
             );
             next PAIR;
         }
@@ -509,9 +529,85 @@ sub _validate_grade_action_pair {
     return scalar(keys %ga_map) ? \%ga_map : undef;
 }
 
+sub _validate_transport {
+    my ($name, $option) = @_;
+    my $transport = '';
+
+    if ( $option =~ /^(\w+)\s?/ ) {
+        $transport = $1;
+        my $full_class = "Test::Reporter::Transport::$transport";
+        eval "use $full_class ()";
+        if ($@) {
+            $CPAN::Frontend->mywarn(
+                "\nCPAN::Reporter: error loading $full_class. Please install the missing module or choose a different transport mechanism.\n\n"
+            );
+        }
+    }
+    else {
+        $CPAN::Frontend->mywarn(
+            "\nCPAN::Reporter: Please provide a transport mechanism.\n\n"
+        );
+        return;
+    }
+
+    # we do extra validation for Metabase and offer to create the profile
+    if ( $transport eq 'Metabase' ) {
+        unless ( $option =~ /\buri\s+\S+/ ) {
+            $CPAN::Frontend->mywarn(
+                "\nCPAN::Reporter: Please provide a target uri.\n\n"
+            );
+            return;
+        }
+
+        unless ( $option =~ /\bid_file\s+(\S.+?)\s*$/ ) {
+            $CPAN::Frontend->mywarn(
+                "\nCPAN::Reporter: Please specify an id_file path.\n\n"
+            );
+            return;
+        }
+
+        my $id_file = $1;
+        unless ( File::Spec->file_name_is_absolute( $id_file ) ) {
+            $id_file = File::Spec->catfile(_get_config_dir(), $id_file);
+        }
+
+        # Offer to create if it doesn't exist
+        if ( ! -e $id_file )  {
+            my $answer = CPAN::Shell::colorable_makemaker_prompt(
+                "Would you like to run 'metabase-profile' now to create '$id_file'?", "y"
+            );
+            if ( $answer =~ /^y/i ) {
+                return _generate_profile( $id_file );
+            }
+            else {
+                $CPAN::Frontend->mywarn( <<"END_ID_FILE" );
+You can create a Metabase profile by typing 'metabase-profile' in your
+command prompt and moving the resulting file to the location you specified.
+If you did not specify an absolute path, put it in your .cpanreporter
+directory.  You will need to do this before continuing.
+END_ID_FILE
+                return;
+            }
+        }
+        # Warn and fail validation if there but not readable
+        elsif (
+            not (       -r $id_file
+                    or  -r File::Spec->catdir(_get_config_dir(), $id_file)
+                )
+        ) {
+            $CPAN::Frontend->mywarn(
+                "CPAN::Reporter: '$id_file' was not readable.\n\n"
+            );
+            return;
+        }
+    } # end Metabase
+
+    return 1;
+}
+
 sub _validate_seconds {
     my ($name, $option) = @_;
-    return unless defined($option) && length($option) 
+    return unless defined($option) && length($option)
         && ($option =~ /^\d/) && $option >= 0;
     return $option;
 }
@@ -535,7 +631,7 @@ CPAN::Reporter::Config - Config file options for CPAN::Reporter
 
 =head1 VERSION
 
-version 1.18_06
+version 1.19_03
 
 =head1 SYNOPSIS
 
@@ -545,8 +641,11 @@ From the CPAN shell:
 
 =head1 DESCRIPTION
 
-Default options for CPAN::Reporter are read from a configuration file 
-C<<< .cpanreporter/config.ini >>> in the user's home directory.
+Default options for CPAN::Reporter are read from a configuration file
+C<<< .cpanreporter/config.ini >>> in the user's home directory.  (On Win32 platforms,
+the directory will be located in the user's "Documents" directory.)
+The location of the configuration directory or file may be specified
+using environment variables instead.
 
 The configuration file is in "ini" format, with the option name and value
 separated by an "=" sign
@@ -554,8 +653,8 @@ separated by an "=" sign
    email_from = "John Doe" <johndoe@nowhere.org>
    edit_report = no
 
-Interactive configuration of email address, mail server and common
-action prompts may be repeated at any time from the CPAN shell.  
+Interactive configuration of email address and common
+action prompts may be repeated at any time from the CPAN shell.
 
   cpan> o conf init test_report
 
@@ -569,57 +668,66 @@ options that have been added manually to the configuration file.
 
 =head2 Email Address (required)
 
+   email_from = <email address>
+
 CPAN::Reporter requires users to provide an email address that will be used
-in the "From" header of the email to cpan-testers@perl.org.
+in the header of the report.
+
+The email address provided should be a valid address format, e.g.:
+
+  email_from = user@domain
+  email_from = John Doe <user@domain>
+  email_from = "John Q. Public" <user@domain>
+
+=head2 Transport (required)
+
+   transport = <transport class> [transport args]
+
+This sets the transport mechanism passed to the C<<< transport() >>> method of
+L<Test::Reporter>. Normally, CPAN::Reporter uses 'Metabase' for transport class
+(i.e. L<Test::Reporter::Transport::Metabase>) and will provide a default set of
+transport arguments.
+
+Metabase transport arguments are two space-separated keyE<sol>value pairs:
 
 =over
 
 =item *
 
-C<<< email_from = <email address> >>> -- email address of the user sending the
-test report; it should be a valid address format, e.g.:
-
-=back
-
-  user@domain
-  John Doe <user@domain>
-  "John Q. Public" <user@domain>
-
-Because C<<< cpan-testers >>> uses a mailing list to collect test reports, it is
-helpful if the email address provided is subscribed to the list.  Otherwise,
-test reports will be held until manually reviewed and approved.  
-
-Subscribing an account to the cpan-testers list is as easy as sending a blank
-email to cpan-testers-subscribe@perl.org and replying to the confirmation
-email.
-
-=head2 Mail Server
-
-By default, Test::Reporter attempts to send mail directly to perl.org mail 
-servers.  This may fail if a user's computer is behind a network firewall 
-that blocks outbound email.  In this case, the following option should
-be set to the outbound mail server (i.e., SMTP server) as provided by
-the user's Internet service provider (ISP):
-
-=over
+C<<< uri >>> -- URI for the Metabase API. Defaults to
+C<<< https://metabase.cpantesters.org/api/v1/ >>>
 
 =item *
 
-C<<< smtp_server = <server list> >>> -- one or more alternate outbound mail servers
-if the default perl.org mail servers cannot be reached; multiple servers may be
-given, separated with a space (none by default)
+C<<< id_file >>> -- path to the user's Metabase profile file.
+Defaults to C<<< metabase_id.json >>>.  (Assumed to be in the C<<< .cpanreporter >>>
+directory).
 
 =back
 
-In at least one reported case, an ISP's outbound mail servers also refused 
-to forward mail unless the C<<< email_from >>> was from the ISP-given email address. 
+Prior to sending reports, a user must have a valid profile file at the path
+specified.  For Metabase transport, CPAN::Reporter will automatically rewrite a
+relative C<<< id_file >>> path as an absolute path located in the C<<< .cpanreporter >>>
+directory.
+
+If the specified profile file does not exist, CPAN::Reporter will offer
+to run C<<< metabase-profile >>> to create it.
+
+For other transport types, see the documentation that comes with your choice of
+Test::Reporter::Transport subclass for the proper way to set the C<<< transport >>>
+configuration option.
 
 =head2 Action Prompts
 
 Several steps in the generation of a test report are optional.  Configuration
 options control whether an action should be taken automatically or whether
-CPAN::Reporter should prompt the user for the action to take.  The action
-to take may be different for each report grade.
+CPAN::Reporter should prompt the user for the action to take.  The action to
+take may be different for each report grade.  For example, users may wish to
+customize for which grades they wish to manually review a report before sending
+it.
+
+Most users should just accept the default settings until they have some
+experience as CPAN Testers.
 
 Valid actions, and their associated meaning, are as follows:
 
@@ -654,7 +762,7 @@ which are processed left to right.
 
 An action by itself is taken as a default to be used for any grade which does
 not have a grade-specific action.  A default action may also be set by using
-the word "default" in place of a grade.  
+the word "default" in place of a grade.
 
   edit_report = ask/no
   edit_report = default:ask/no
@@ -673,7 +781,7 @@ The action prompt options included in interactive configuration are:
 
 =item *
 
-C<<< edit_report = <grade:action> ... >>> -- edit the test report before sending? 
+C<<< edit_report = <grade:action> ... >>> -- edit the test report before sending?
 (default:askE<sol>no passE<sol>na:no)
 
 =item *
@@ -691,10 +799,15 @@ C<<< test_report >>>:
 
   cpan> o conf test_report 0
 
+=head2 Mail Server (DEPRECATED)
+
+CPAN::Reporter used to send mail directly to perl.org mail servers. The
+C<<< smtp_server >>> option is now deprecated and will be ignored if it exists.
+
 =head1 ADVANCED CONFIGURATION OPTIONS
 
 These additional options are only necessary in special cases, for example if
-the default editor cannot be found or if reports shouldn't be sent in 
+the default editor cannot be found or if reports shouldn't be sent in
 certain situations or for automated testing, and so on.
 
 =over
@@ -702,52 +815,46 @@ certain situations or for automated testing, and so on.
 =item *
 
 C<<< command_timeout >>> -- if greater than zero and the CPAN config is
-C<<< inactivity_timeout >>> is not set, then any commands executed by CPAN::Reporter 
-will be halted after this many seconds; useful for unattended smoke testing 
-to stop after some amount of time; generally, this should be large -- 
-900 seconds or more -- as some distributions' tests take quite a long time to 
-run.  On MSWin32, L<Win32::Job> is a needed and trying to kill a processes may 
+C<<< inactivity_timeout >>> is not set, then any commands executed by CPAN::Reporter
+will be halted after this many seconds; useful for unattended smoke testing
+to stop after some amount of time; generally, this should be large --
+900 seconds or more -- as some distributions' tests take quite a long time to
+run.  On MSWin32, L<Win32::Job> is a needed and trying to kill a processes may
 actually deadlock in some situations -- so use at your own risk.
 
 =item *
 
 C<<< editor = <editor> >>> -- editor to use to edit the test report; if not set,
 Test::Reporter will use environment variables C<<< VISUAL >>>, C<<< EDITOR >>> or C<<< EDIT >>>
-(in that order) to find an editor 
+(in that order) to find an editor
 
 =item *
 
-C<<< send_duplicates = <grade:action> ... >>> -- should duplicates of previous 
+C<<< send_duplicates = <grade:action> ... >>> -- should duplicates of previous
 reports be sent, regardless of C<<< send_report >>>? (default:no)
 
 =item *
 
-C<<< send_PL_report = <grade:action> ... >>> -- if defined, used in place of 
+C<<< send_PL_report = <grade:action> ... >>> -- if defined, used in place of
 C<<< send_report >>> during the PL phase
 
 =item *
 
-C<<< send_make_report = <grade:action> ... >>> -- if defined, used in place of 
+C<<< send_make_report = <grade:action> ... >>> -- if defined, used in place of
 C<<< send_report >>> during the make phase
 
 =item *
 
-C<<< send_test_report = <grade:action> ... >>> -- if defined, used in place of 
+C<<< send_test_report = <grade:action> ... >>> -- if defined, used in place of
 C<<< send_report >>> during the test phase
 
 =item *
 
 C<<< send_skipfile = <skipfile> >>> -- filename containing regular expressions (one
-per line) to match against the distribution ID (e.g. 
-'AUTHORE<sol>Dist-Name-0.01.tar.gz'); the report will not be sent if a match is 
+per line) to match against the distribution ID (e.g.
+'AUTHORE<sol>Dist-Name-0.01.tar.gz'); the report will not be sent if a match is
 found; non-absolute filename must be in the .cpanreporter config directory;
 
-=item *
-
-C<<< transport = <transport> [transport args] >>> -- if defined, passed to the 
-C<<< transport() >>> method of L<Test::Reporter>.  See below for 
-more details.  (CPAN::Reporter uses 'Net::SMTP' for this by default.)
-
 =back
 
 If these options are manually added to the configuration file, they will
@@ -755,19 +862,19 @@ be included (and preserved) in subsequent interactive configuration.
 
 =head2 Skipfile regular expressions
 
-Skip files are expected to have one regular expression per line and will be 
-matched against the distribution ID, composed of the author's CPAN ID and the 
+Skip files are expected to have one regular expression per line and will be
+matched against the distribution ID, composed of the author's CPAN ID and the
 distribution tarball name.
 
      DAGOLDEN/CPAN-Reporter-1.00.tar.gz
 
 Lines that begin with a sharp (#) are considered comments and will not be
 matched.  All regular expressionss will be matched case insensitive and will
-not be anchored unless you provide one. 
+not be anchored unless you provide one.
 
-As the format of a distribution ID is "AUTHORE<sol>tarball", anchoring at the 
+As the format of a distribution ID is "AUTHORE<sol>tarball", anchoring at the
 start of the line with a caret (^) will match the author and with a slash (E<sol>)
-will match the distribution.  
+will match the distribution.
 
      # any distributions by JOHNDOE
      ^JOHNDOE
@@ -776,24 +883,6 @@ will match the distribution.
      # a particular very specific distribution
      ^JOHNDOE/Foo-Bar-3.14
 
-=head2 Transport options
-
-The L<Test::Reporter> 1.39_XX development series added support for multiple
-transport modules, e.g. L<Test::Reporter::Transport::Net::SMTP::TLS> or
-L<Test::Reporter::Transport::HTTPGateway>.  To use them with CPAN::Reporter,
-set the 'transport' config option to the name of the transport module 
-(without the 'Test::Reporter::Transport' prefix) and any required arguments,
-separated by white space. For example:
-
-   transport=Net::SMTP Port 587
-   transport=Net::SMTP::TLS User jdoe@example.com Password 12345
-   transport=HTTPGateway http://example.com/cpantesters.cgi MyKey
-   transport=File ~/saved-reports-dir
-
-The transport module may be any Test::Reporter::Transport installed on your
-system.  As of Test::Reporter 1.39_05, transports included 'Net::SMTP', 
-'Net::SMTP::TLS', 'Mail::Send',  'HTTPGateway' and 'File'.
-
 =head1 CONFIGURATION OPTIONS FOR DEBUGGING
 
 These options are useful for debugging only:
@@ -804,16 +893,11 @@ These options are useful for debugging only:
 
 C<<< debug = <boolean> >>> -- turns debugging onE<sol>off
 
-=item *
-
-C<<< email_to = <email address> >>> -- alternate destination for reports instead of
-C<<< cpan-testers@perl.org >>>; used for testing
-
 =back
 
 =head1 ENVIRONMENT
 
-The following environment variables may be set to alter the default locations 
+The following environment variables may be set to alter the default locations
 for CPAN::Reporter files:
 
 =over
@@ -821,15 +905,15 @@ for CPAN::Reporter files:
 =item *
 
 C<<< PERL_CPAN_REPORTER_DIR >>> -- if set, this directory is used in place of
-the default .cpanreporter directory; this will affect not only the location
-of the default C<<< config.ini >>>, but also the location of the 
+the default C<<< .cpanreporter >>> directory; this will affect not only the location
+of the default C<<< config.ini >>>, but also the location of the
 L<CPAN::Reporter::History> database and any other files that live in that
 directory
 
 =item *
 
-C<<< PERL_CPAN_REPORTER_CONFIG >>> -- if set, this file is used in place of 
-the default C<<< config.ini >>> file; it may be in any directory, regardless of the 
+C<<< PERL_CPAN_REPORTER_CONFIG >>> -- if set, this file is used in place of
+the default C<<< config.ini >>> file; it may be in any directory, regardless of the
 choice of configuration directory
 
 =back
@@ -852,24 +936,7 @@ L<CPAN::Reporter::FAQ>
 
 =back
 
-=head1 AUTHOR
-
-David A. Golden (DAGOLDEN)
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (c) 2006, 2007, 2008 by David A. Golden
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at 
-L<http://www.apache.org/licenses/LICENSE-2.0>
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+# vim: ts=4 sts=4 sw=4 et:
 
 =head1 AUTHOR
 
